==> mlt.docreg_1.1-5.tar.gz: mlt.docreg/inst/NEWS.Rd <==

\name{NEWS}
\title{NEWS file for the mlt.docreg package}


\section{Changes in Version 1.1-5 (2022-06-21)}{
  \itemize{
    \item{Packages \pkg{MIICD} and \pkg{coxinterval} were removed from CRAN.}
  }
}

\section{Changes in Version 1.1-4 (2022-05-18)}{
  \itemize{
    \item{Package \pkg{ICE} was removed from CRAN.}
    \item{Update checks.}
  }
}


\section{Changes in Version 1.1-3 (2022-01-12)}{
  \itemize{
    \item{Remove ignored arguments from \code{mlt}.}
  }
}


\section{Changes in Version 1.1-2 (2021-12-16)}{
  \itemize{
    \item{Update reference output for truncation examples.}
  }
}


\section{Changes in Version 1.1-1 (2021-12-07)}{
  \itemize{
    \item{Fix LaTeX problems.}
    \item{Reduce precision in reported estimates, this makes M1mac happy again.}
    \item{Update reference output for truncation examples.}
  }
}

\section{Changes in Version 1.1-0 (2021-03-08)}{
  \itemize{
    \item{New regression test for nonparametric ML estimation
          using \code{tram::Polr}, compare with \code{rms::orm}.
          The latter is much faster but less flexible.}
  }
}


\section{Changes in Version 1.0-10 (2021-02-23)}{
  \itemize{
    \item{Suppress warnings from package \pkg{flexsurv}.}
  }
}



\section{Changes in Version 1.0-9 (2020-12-15)}{
  \itemize{
    \item{\pkg{eha} doesn't import \pkg{survival} anymore; fix regression test.}
  }
}


\section{Changes in Version 1.0-8 (2020-09-21)}{
  \itemize{
    \item{Catch file download problems in vignette.}
  }
}


\section{Changes in Version 1.0-7 (2020-08-31)}{
  \itemize{
    \item{Make everything conditional on suggested packages being available, really.}
  }
}


\section{Changes in Version 1.0-6 (2020-08-27)}{
  \itemize{
    \item{Make everything conditional on suggested packages being available.}
  }
}


\section{Changes in Version 1.0-5 (2020-02-13)}{
  \itemize{
    \item{Update reference output.}
  }
}


\section{Changes in Version 1.0-4 (2020-01-09)}{
  \itemize{
    \item{Update reference output.}
  }
}


\section{Changes in Version 1.0-3 (2019-06-20)}{
  \itemize{
    \item{Update to \pkg{mlt} 1.0-5.}
  }
}
\section{Changes in Version 1.0-2 (2018-08-15)}{
  \itemize{
    \item{\code{compress} argment to \code{untar} is deprecated in R-devel.}
  }
}

\section{Changes in Version 1.0-1 (2018-06-22)}{
  \itemize{
    \item{Documentation updates.}
    \item{Update to \pkg{mlt} 1.0-2.}
  }
}


\section{Changes in Version 1.0-0 (2018-03-07)}{
  \itemize{
    \item{A paper describing version 1.0-0 of the \pkg{mlt}, \pkg{basefun}, and
          \pkg{variables} packages was accepted for publication in the Journal of
          Statistical Software 2018-03-05.}
    \item{Documentation updates.}
  }
}

\section{Changes in Version 0.2-2 (2018-02-27)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.2-2.}
    \item{Vignette updates; add link to simpler interfaces
          in \pkg{tram}.}
  }
}

\section{Changes in Version 0.2-1 (2017-12-12)}{
  \itemize{
    \item{Update citations.}
  }
}


\section{Changes in Version 0.2-0 (2017-06-20)}{
  \itemize{
    \item{Most Likely Transformations will be published in
          the Scandinavian Journal of Statistics.}
    \item{Update to \code{mlt} 0.2-0.}
    \item{Remove \pkg{alabama} from Suggests as it is imported by
          \pkg{mlt} now.}
  }
}


\section{Changes in Version 0.1-5 (2017-04-04)}{
  \itemize{
    \item{Update to \code{mlt} 0.1-3.}
    \item{Improvements in package vignette (mainly thanks to Eva Furrer).}
  }
}

\section{Changes in Version 0.1-4 (2016-12-04)}{
  \itemize{
    \item{More tests were a little too strict on non-Linux platforms.}
    \item{\code{auglag} does not seem to converge to the ML estimate for the
          tree pipit example; force \code{sgp} to be used.}
  }
}


\section{Changes in Version 0.1-3 (2016-12-01)}{
  \itemize{
    \item{Some tests were a little too strict on non-Linux platforms.}
  }
}

\section{Changes in Version 0.1-2 (2016-11-29)}{
  \itemize{
    \item{Add tests for survival models with time-dependent covariates.}
  }
}

\section{Changes in Version 0.1-1 (2016-11-17)}{
  \itemize{
    \item{Some fixes in vignette.}
  }
}

\section{Changes in Version 0.1-0 (2016-11-09)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.1-0; small fixes in vignette and reference outputs.}
  }
}

\section{Changes in Version 0.0-33 (2016-09-12)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.0-34; small fixes in vignette.}
  }
}

\section{Changes in Version 0.0-32 (2016-05-25)}{
  \itemize{
    \item{Remove \pkg{intcox} as the package is archived now.}
  }
}

\section{Changes in Version 0.0-30 (2016-02-23)}{
  \itemize{
    \item{The \pkg{mlt.docreg} package was first 
          published on CRAN.}
  }
}

==> mlt.docreg_1.1-6.tar.gz: mlt.docreg/inst/NEWS.Rd <==

\name{NEWS}
\title{NEWS file for the mlt.docreg package}


\section{Changes in Version 1.1-6 (2022-08-15)}{
  \itemize{
    \item{Package \pkg{np} is scheduled for removal from CRAN.}
  }
}


\section{Changes in Version 1.1-5 (2022-06-21)}{
  \itemize{
    \item{Packages \pkg{MIICD} and \pkg{coxinterval} were removed from CRAN.}
  }
}


\section{Changes in Version 1.1-4 (2022-05-18)}{
  \itemize{
    \item{Package \pkg{ICE} was removed from CRAN.}
    \item{Update checks.}
  }
}


\section{Changes in Version 1.1-3 (2022-01-12)}{
  \itemize{
    \item{Remove ignored arguments from \code{mlt}.}
  }
}


\section{Changes in Version 1.1-2 (2021-12-16)}{
  \itemize{
    \item{Update reference output for truncation examples.}
  }
}


\section{Changes in Version 1.1-1 (2021-12-07)}{
  \itemize{
    \item{Fix LaTeX problems.}
    \item{Reduce precision in reported estimates, this makes M1mac happy again.}
    \item{Update reference output for truncation examples.}
  }
}

\section{Changes in Version 1.1-0 (2021-03-08)}{
  \itemize{
    \item{New regression test for nonparametric ML estimation
          using \code{tram::Polr}, compare with \code{rms::orm}.
          The latter is much faster but less flexible.}
  }
}


\section{Changes in Version 1.0-10 (2021-02-23)}{
  \itemize{
    \item{Suppress warnings from package \pkg{flexsurv}.}
  }
}



\section{Changes in Version 1.0-9 (2020-12-15)}{
  \itemize{
    \item{\pkg{eha} doesn't import \pkg{survival} anymore; fix regression test.}
  }
}


\section{Changes in Version 1.0-8 (2020-09-21)}{
  \itemize{
    \item{Catch file download problems in vignette.}
  }
}


\section{Changes in Version 1.0-7 (2020-08-31)}{
  \itemize{
    \item{Make everything conditional on suggested packages being available, really.}
  }
}


\section{Changes in Version 1.0-6 (2020-08-27)}{
  \itemize{
    \item{Make everything conditional on suggested packages being available.}
  }
}


\section{Changes in Version 1.0-5 (2020-02-13)}{
  \itemize{
    \item{Update reference output.}
  }
}


\section{Changes in Version 1.0-4 (2020-01-09)}{
  \itemize{
    \item{Update reference output.}
  }
}


\section{Changes in Version 1.0-3 (2019-06-20)}{
  \itemize{
    \item{Update to \pkg{mlt} 1.0-5.}
  }
}
\section{Changes in Version 1.0-2 (2018-08-15)}{
  \itemize{
    \item{\code{compress} argment to \code{untar} is deprecated in R-devel.}
  }
}

\section{Changes in Version 1.0-1 (2018-06-22)}{
  \itemize{
    \item{Documentation updates.}
    \item{Update to \pkg{mlt} 1.0-2.}
  }
}


\section{Changes in Version 1.0-0 (2018-03-07)}{
  \itemize{
    \item{A paper describing version 1.0-0 of the \pkg{mlt}, \pkg{basefun}, and
          \pkg{variables} packages was accepted for publication in the Journal of
          Statistical Software 2018-03-05.}
    \item{Documentation updates.}
  }
}

\section{Changes in Version 0.2-2 (2018-02-27)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.2-2.}
    \item{Vignette updates; add link to simpler interfaces
          in \pkg{tram}.}
  }
}

\section{Changes in Version 0.2-1 (2017-12-12)}{
  \itemize{
    \item{Update citations.}
  }
}


\section{Changes in Version 0.2-0 (2017-06-20)}{
  \itemize{
    \item{Most Likely Transformations will be published in
          the Scandinavian Journal of Statistics.}
    \item{Update to \code{mlt} 0.2-0.}
    \item{Remove \pkg{alabama} from Suggests as it is imported by
          \pkg{mlt} now.}
  }
}


\section{Changes in Version 0.1-5 (2017-04-04)}{
  \itemize{
    \item{Update to \code{mlt} 0.1-3.}
    \item{Improvements in package vignette (mainly thanks to Eva Furrer).}
  }
}

\section{Changes in Version 0.1-4 (2016-12-04)}{
  \itemize{
    \item{More tests were a little too strict on non-Linux platforms.}
    \item{\code{auglag} does not seem to converge to the ML estimate for the
          tree pipit example; force \code{sgp} to be used.}
  }
}


\section{Changes in Version 0.1-3 (2016-12-01)}{
  \itemize{
    \item{Some tests were a little too strict on non-Linux platforms.}
  }
}

\section{Changes in Version 0.1-2 (2016-11-29)}{
  \itemize{
    \item{Add tests for survival models with time-dependent covariates.}
  }
}

\section{Changes in Version 0.1-1 (2016-11-17)}{
  \itemize{
    \item{Some fixes in vignette.}
  }
}

\section{Changes in Version 0.1-0 (2016-11-09)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.1-0; small fixes in vignette and reference outputs.}
  }
}

\section{Changes in Version 0.0-33 (2016-09-12)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.0-34; small fixes in vignette.}
  }
}

\section{Changes in Version 0.0-32 (2016-05-25)}{
  \itemize{
    \item{Remove \pkg{intcox} as the package is archived now.}
  }
}

\section{Changes in Version 0.0-30 (2016-02-23)}{
  \itemize{
    \item{The \pkg{mlt.docreg} package was first 
          published on CRAN.}
  }
}
